@@ -124,7 +124,6 @@ CREATE TABLE `contactgroupmembers` (
 ALTER TABLE `users` CHANGE `last_login` `last_login` datetime DEFAULT NULL;
 UPDATE `users` SET `last_login` = NULL WHERE `last_login` = '1000-01-01 00:00:00';
 
--- Updates from version 0.4
 -- Updates from version 0.4.2
 
 ALTER TABLE `users` DROP INDEX `username_index`;
@@ -148,6 +147,8 @@ TRUNCATE TABLE `cache`;
 
 -- Updates from version 0.6
 
+/*!40014 SET FOREIGN_KEY_CHECKS=0 */;
+
 ALTER TABLE `users` CHANGE `alias` `alias` varchar(128) BINARY NOT NULL;
 ALTER TABLE `users` CHANGE `username` `username` varchar(128) BINARY NOT NULL;
 
@@ -210,15 +211,19 @@ CREATE TABLE `cache_messages` (
  PRIMARY KEY (`user_id`, `mailbox`, `uid`)
 ) /*!40000 ENGINE=INNODB */ /*!40101 CHARACTER SET utf8 COLLATE utf8_general_ci */;
 
+/*!40014 SET FOREIGN_KEY_CHECKS=1 */;
+
 -- Updates from version 0.7-beta
 
 ALTER TABLE `session` CHANGE `sess_id` `sess_id` varchar(128) NOT NULL;
 
 -- Updates from version 0.7
 
+/*!40014 SET FOREIGN_KEY_CHECKS=0 */;
+
 ALTER TABLE `contacts` DROP FOREIGN KEY `user_id_fk_contacts`;
 ALTER TABLE `contacts` DROP INDEX `user_contacts_index`;
-ALTER TABLE `contacts` MODIFY `email` text NOT NULL DEFAULT '';
+ALTER TABLE `contacts` MODIFY `email` text NOT NULL;
 ALTER TABLE `contacts` ADD INDEX `user_contacts_index` (`user_id`,`del`);
 ALTER TABLE `contacts` ADD CONSTRAINT `user_id_fk_contacts` FOREIGN KEY (`user_id`)
    REFERENCES `users`(`user_id`) ON DELETE CASCADE ON UPDATE CASCADE;
@@ -232,3 +237,12 @@ ALTER TABLE `contactgroups` ALTER `user_id` DROP DEFAULT;
 ALTER TABLE `contactgroupmembers` ALTER `contact_id` DROP DEFAULT;
 ALTER TABLE `identities` ALTER `user_id` DROP DEFAULT;
 ALTER TABLE `searches` ALTER `user_id` DROP DEFAULT;
+
+/*!40014 SET FOREIGN_KEY_CHECKS=1 */;
+
+-- Updates from version 0.7.1
+-- Updates from version 0.7.2
+-- Updates from version 0.8
+-- Updates from version 0.8.1
+-- Updates from version 0.8.2
+-- Updates from version 0.8.3
